@@ -3,7 +3,7 @@ use warnings;
 use v5.8.0;
 
 package Dist::Zilla::Plugin::NexusRelease;
-$Dist::Zilla::Plugin::NexusRelease::VERSION = '1.0.0';
+$Dist::Zilla::Plugin::NexusRelease::VERSION = '1.0.1';
 
 # ABSTRACT: Release a Dist::Zilla build to a Sonatype Nexus instance.
 
@@ -12,6 +12,7 @@ use Moose;
 with 'Dist::Zilla::Role::Releaser';
 
 use Log::Any qw($log);
+use Moose::Util::TypeConstraints;
 use Scalar::Util qw(weaken);
 use Carp;
 
@@ -20,7 +21,7 @@ use namespace::autoclean;
 {
 
     package Dist::Zilla::Plugin::NexusRelease::_Uploader;
-$Dist::Zilla::Plugin::NexusRelease::_Uploader::VERSION = '1.0.0';
+$Dist::Zilla::Plugin::NexusRelease::_Uploader::VERSION = '1.0.1';
     # Nexus::Uploader will be loaded later if used
     our @ISA = 'Nexus::Uploader';
 
@@ -31,6 +32,28 @@ $Dist::Zilla::Plugin::NexusRelease::_Uploader::VERSION = '1.0.0';
 }
 
 
+has credentials_stash => (
+    is      => 'ro',
+    isa     => 'Str',
+    default => '%Nexus'
+);
+
+has _credentials_stash_obj => (
+    is       => 'ro',
+    isa      => maybe_type( class_type('Dist::Zilla::Stash::Nexus') ),
+    lazy     => 1,
+    init_arg => undef,
+    default  => sub { $_[0]->zilla->stash_named( $_[0]->credentials_stash ) },
+);
+
+sub _credential {
+    my ( $self, $name ) = @_;
+
+    return unless my $stash = $self->_credentials_stash_obj;
+    return $stash->$name;
+}
+
+
 has username => (
     is       => 'ro',
     isa      => 'Str',
@@ -38,7 +61,8 @@ has username => (
     lazy     => 1,
     default  => sub {
         my $self = shift;
-        return $self->zilla->chrome->prompt_str('Nexus username: ');
+        return $self->_credential('username')
+            || $self->zilla->chrome->prompt_str('Nexus username: ');
     }
 );
 
@@ -50,7 +74,8 @@ has password => (
     lazy     => 1,
     default  => sub {
         my $self = shift;
-        return $self->zilla->chrome->prompt_str( 'Nexus password: ',
+        return $self->_credential('password')
+            || $self->zilla->chrome->prompt_str( 'Nexus password: ',
             { noecho => 1 } );
     }
 );
@@ -151,7 +176,7 @@ Dist::Zilla::Plugin::NexusRelease - Release a Dist::Zilla build to a Sonatype Ne
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 SYNOPSIS
 
@@ -175,17 +200,23 @@ The Nexus Artefact is set to the Perl distribution name (C<name> in F<dist.ini>,
 
 =head1 ATTRIBUTES
 
+=head2 credentials_stash
+
+This attribute holds the name of a L<Nexus stash|Dist::Zilla::Stash::Nexus>
+that will contain the credentials to be used for the upload.  By default,
+NexusRelease will look for a C<%Nexus> stash.
+
 =head2 username
 
 This is the Nexus user to log in with.
 
-User will be prompted if this is not set in F<dist.ini>.
+User will be prompted if this is not set in the C<%Nexus> stash.
 
 =head2 password
 
 The Nexus password. It is *strongly* advised that you take advantage of the Nexus user tokens feature!
 
-User will be prompted if this is not set in F<dist.ini>.
+User will be prompted if this is not set in the C<%Nexus> stash.
 
 =head2 nexus_URL
 
